@@ -5,22 +5,23 @@ Usage:
 ------
     $ flatland [-m model] [-l layout] [-d diagram]
 """
-import os
+# import os
 import sys
 import argparse
 from pathlib import Path
+# from flatland.xUML.XumlClassDiagram import XumlClassDiagram
+from xUML.XumlClassDiagram import XumlClassDiagram
 
 # When launched outside of the PyCharm development environment, we need to include all source folders
 # in the sys.path or the flatland imports will fail
 # (PyCharm appends all the source roots automatically)
-pycharm_launch = os.getenv('PYCHARM_LAUNCH')  # Don't forget to set this variable in the run/debug configs
-if not pycharm_launch:
-    myroot = Path(__file__).parent
-    sys.path.insert(1, str(myroot / "Connector Subsystem"))
-    sys.path.insert(1, str(myroot / "Node Subsystem"))
-    sys.path.insert(1, str(myroot / "xUML"))
+# pycharm_launch = os.getenv('PYCHARM_LAUNCH')  # Don't forget to set this variable in the run/debug configs
+# if not pycharm_launch:
+#     myroot = Path(__file__).parent
+#     sys.path.insert(1, str(myroot / "Connector Subsystem"))
+#     sys.path.insert(1, str(myroot / "Node Subsystem"))
+#     sys.path.insert(1, str(myroot / "xUML"))
 
-from flatland.xUML.XumlClassDiagram import XumlClassDiagram
 
 # Configure the expected parameters and actions for the argparse module
 def parse(cl_input):
